#
# spec file for package perl-Crypt-JWT
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Crypt-JWT
Name:           perl-Crypt-JWT
Version:        0.36.0
Release:        1.1
# 0.036 -> normalize -> 0.36.0
%define cpan_version 0.036
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        JSON Web Token
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MI/MIK/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Compress::Raw::Zlib)
BuildRequires:  perl(CryptX) >= 0.067
BuildRequires:  perl(JSON)
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(Compress::Raw::Zlib)
Requires:       perl(CryptX) >= 0.067
Requires:       perl(JSON)
Requires:       perl(Test::More) >= 0.88
Provides:       perl(Crypt::JWT) = %{version}
Provides:       perl(Crypt::KeyWrap) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
Implements *JSON Web Token (JWT)* - https://tools.ietf.org/html/rfc7519.
The implementation covers not only *JSON Web Signature (JWS)* -
https://tools.ietf.org/html/rfc7515, but also *JSON Web Encryption (JWE)* -
https://tools.ietf.org/html/rfc7516.

The module implements *all (100%) algorithms* defined in
https://tools.ietf.org/html/rfc7518 - *JSON Web Algorithms (JWA)*.

This module supports *Compact JWS/JWE* and *Flattened JWS/JWE JSON*
serialization, general JSON serialization is not supported yet.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.md
%license LICENSE

%changelog
* Mon Jan 27 2025 Tina Müller <timueller+perl@suse.de>
- updated to 0.36.0 (0.036)
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.036   2025-01-26
  - fix #35 support aud claim as an array of strings
  - added verify_typ - verify 'typ' header parameter
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Wed Oct  4 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.035
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.035   2023-10-03
  - PR #37 Speed up decode_jwt
* Mon Nov 29 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.034
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.034   2021-11-28
  - fix #32 ensure payload is serialized consistently (canonical)
* Sun May  2 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.033
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.033   2021-05-01
  - fix #31 verify_xxx options do not work properly with decode_payload=0
* Fri Mar 19 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.032
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.032   2021-03-18
  - fix #30 use lower uid/gid in release tarball
* Mon Jan 11 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.031
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.031   2021-01-10
  - fix #29 Broken JWS support for ES256K "alg" type
  0.030   2021-01-08
  - fix #28 Using "kid_keys" with PS256 fails
* Tue Jun 23 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.029
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.029   2020-06-22
  - verify_iss, verify_aud, verify_sub, verify_jti accept Scalar
* Mon Jun 15 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.028
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.028   2020-06-14
  - switch to JSON from JSON::MaybeXS
* Fri Jun  5 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.027
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.027   2020-06-05
  - fix #25 more intuitive exceptions
  - support for ES256K
* Mon Feb  3 2020 <timueller+perl@suse.de>
- updated to 0.026
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.026   2019-02-02
  - added support for EdDSA/ed25519 + ECDH/x25519
  - fix #21 Potentially wrong IV in gcm_key_wrap
* Mon Sep 30 2019 <timueller+perl@suse.de>
- updated to 0.025
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.025   2019-09-29
  - fix #19 Empty payload in JWS JSON token
  - PR #18 _verify_claims: Refactor iss, sub, aud, and jti checks
* Wed Mar 27 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.024
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
* Wed Sep 19 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.023
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
* Mon Jun 25 2018 coolo@suse.com
- updated to 0.022
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.022   2018/06/24
  - fix AESGCM IV size as required by RFC (in encrypt_jwe_payload)
* Fri Mar 16 2018 coolo@suse.com
- updated to 0.021
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.021   2018/03/15
  - fix #13 off-by-one in exp verification
* Wed Feb  7 2018 coolo@suse.com
- updated to 0.020
  see /usr/share/doc/packages/perl-Crypt-JWT/Changes
  0.020   2018/02/02
  - improved diagnostics
  0.019   2018/01/26
  - fix #11 kid keys
  - fix #9  Support for Java lib that pads base64 encoding
* Wed Aug 30 2017 rjschwei@suse.com
- Fix package name in spec file, cut and paste error
* Tue Aug 15 2017 rjschwei@suse.com
- Initial build
  + Version 0.018
